ewa.ply.yacc.NullLogger

Package ewa :: Package ply :: Module yacc :: Class NullLogger |
[hide private]
[frames] | no frames]

# Class NullLogger

source code

    object --+
             |
            NullLogger

Instance Methods | [hide private]
__getattribute__(self, name) x.__getattribute__('name') <==> x.name | source code
__call__(self, *args, **kwargs) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __getattribute__(self, name) | source code
x.__getattribute__('name') <==> x.name Overrides: object.__getattribute__ (inherited documentation)